use xmpd_settings::theme::Theme;

use crate::{components::CompUi, GuiState};

pub fn draw(ctx: &egui::Context, state: &mut GuiState) -> crate::Result<()> {
    // The central panel the region left after adding TopPanel's and SidePanel's
    // ui.heading(format!("Songs ({})", self.manifest.get_song_count()));
    let theme = xmpd_settings::Settings::get()?.theme.clone();
    egui::TopBottomPanel::new(egui::panel::TopBottomSide::Top, "top_nav")
        .frame(get_themed_frame(&theme))
        .show(ctx, |ui| {
            ui.style_mut().visuals.override_text_color = Some(theme.text_color);
            handle_error_ui!(crate::components::top_nav::TopNav::draw(ui, state));
        }
    );
    egui::CentralPanel::default()
        .frame(get_themed_frame(&theme))
        .show(ctx, |ui| {
            let avail = ui.available_size();
            ui.vertical(|ui| {
                crate::utils::super_separator(ui, theme.accent_color, avail.x, 2.0);
                let avail = ui.available_size();
                let main_height = avail.y * 0.91;

                ui.horizontal(|ui| {
                    ui.set_height(main_height);  
                    ui.group(|ui| {
                        ui.set_height(main_height);
                        ui.set_max_width((avail.x * 0.25).clamp(0.0, 200.0));
                        handle_error_ui!(crate::components::left_nav::LeftNav::draw(ui, state));
                    });
                    ui.vertical(|ui| {
                        ui.group(|ui| {
                            ui.set_width(avail.x * 0.75);
                            handle_error_ui!(crate::components::song_list::song_list_nav::SongListNav::draw(ui, state));
                        });
                        ui.group(|ui| {
                            handle_error_ui!(crate::components::song_list::SongList::draw(ui, state));
                        });
                    });
                });
                
            });
        }
    );

    egui::TopBottomPanel::new(egui::panel::TopBottomSide::Bottom, "player")
        .frame(get_themed_frame(&theme))
        .show(ctx, |ui| {
            ui.style_mut().visuals.override_text_color = Some(theme.text_color);
            handle_error_ui!(crate::components::player::Player::draw(ui, state));
        }
    );
    Ok(())
}

fn get_themed_frame(theme: &Theme) -> egui::Frame {
    egui::Frame::none()
        .fill(theme.primary_bg_color)
        .stroke(egui::Stroke::new(
            1.0,
            theme.secondary_bg_color,
        ))
}


